@@ -88,3 +88,6 @@ AWS_ELASTICACHE_BACKUP_CANONICAL_IDS = [
     "40fa568277ad703bd160f66ae4f83fc9dfdfd06c2f1b5060ca22442ac3ef8be6",  # AWS GovCloud (US-West) Region
     "540804c33a284a299d2547575ce1010f2312ef3da9b3a053c8bc45bf233e4353",  # All other AWS Regions
 ]
+
+MIN_PORT_NUMBER = 0
+MAX_PORT_NUMBER = 65535
