@@ -3,11 +3,10 @@ import re
 """
 Check for Principals where root is being used.
 Valid:
-- arn:aws:iam::437628376:root
-- arn:aws:iam::344345345:root
+- arn:aws:iam::123456789012:root
 - arn:aws:iam:::root
 Invalid:
-- arn:aws:iam::437628376:not-root
+- arn:aws:iam::123456789012:not-root
 - potato
 """
 REGEX_CROSS_ACCOUNT_ROOT = re.compile(r"arn:aws:iam::\d*:root")
@@ -16,13 +15,15 @@ REGEX_CROSS_ACCOUNT_ROOT = re.compile(r"arn:aws:iam::\d*:root")
 Check for use of wildcard in two bad cases: full wildcard, or wildcard in account ID.
 Valid:
 - *
+- ?*
+- **
 - arn:aws:iam::*:12345
 Invalid:
-- arn:aws:iam::444455556666:root
+- arn:aws:iam::123456789012:root
 - potato
-- arn:aws:iam::12345:*
+- arn:aws:iam::123456789012:*
 """
-REGEX_FULL_WILDCARD_PRINCIPAL = re.compile(r"^((\w*:){0,1}\*|arn:aws:iam::\*:.*)$")
+REGEX_FULL_WILDCARD_PRINCIPAL = re.compile(r"^((\w*:)?[*?]+|arn:aws:iam::[*?]+:.*)$")
 
 """
 Check for use of wildcard or account-wide principals.
@@ -30,13 +31,14 @@ Valid:
 - arn:aws:iam::123456789012:*
 - arn:aws:iam::123456789012:service-*
 - arn:aws:iam::123456789012:root
+- arn:aws:iam::123456789012:*-role
 - 123456789012
 Invalid:
 - *
 - potato
-- arn:aws:iam::123456789012:*not-root
+- arn:aws:iam::123456789012:not-root
 """
-REGEX_PARTIAL_WILDCARD_PRINCIPAL = re.compile(r"^\d{12}|arn:aws:iam::.*:(.*\*|root)$")
+REGEX_PARTIAL_WILDCARD_PRINCIPAL = re.compile(r"^(\d+)|(arn:aws:iam::(\d+):(.*[*?]+|[*?]+.*|root))$")
 
 """
 Check for use of wildcard, when applied to the specific elements of an Action.
@@ -44,22 +46,25 @@ For example, sts:AssumeRole* or sts:*. This regex is not checking for use of `*`
 Valid:
 - sts:AssumeRole*
 - sts:*
+- sts:Assume????
+- sts:??????Role
+- sts:*Role*
 Invalid:
 - sts:AssumeRole
 - sts:AssumeRole-Thing-This
 - *
 """
-REGEX_WILDCARD_POLICY_ACTION = re.compile(r"^(\w*:)(\w*)\*(\w*)$")
+REGEX_WILDCARD_POLICY_ACTION = re.compile(r"^(\w*:)(.*)[*?]+(.*)$")
 
 """
-Check for Principals where root is being used.
+Check for Principals where a star is being used.
 Valid:
 - *
 - abc*def
 - abcdef*
 - *abcdef
 Invalid:
-- arn:aws:iam::437628376:not-root
+- arn:aws:iam::123456789012:not-root
 - potato
 """
 REGEX_CONTAINS_STAR = re.compile(r"^.*[*].*$")
@@ -73,7 +78,7 @@ Invalid:
 - abc*def
 - abcdef*
 - *abcdef
-- arn:aws:iam::437628376:not-root
+- arn:aws:iam::123456789012:not-root
 - potato
 """
 REGEX_IS_STAR = re.compile(r"^\*$")
@@ -84,8 +89,8 @@ Check for arns
 It has 4 groups. The first one for service name, the second one for region, the third, for account id, the last one
 for resource id
 Valid:
-- arn:aws:iam::437628376:not-root
-- arn:aws:iam::437628376:root
+- arn:aws:iam::123456789012:not-root
+- arn:aws:iam::123456789012:root
 - arn:aws:s3:::my_corporate_bucket
 Invalid:
 - potato
@@ -102,40 +107,42 @@ Valid:
 Invalid:
 - potato
 - arn:aws:s3:::my_corporate_bucket
-- arn:aws:iam::437628376:root
+- arn:aws:iam::123456789012:root
 """
-REGEX_WILDCARD_ARN = re.compile(r"^arn:aws:([*\w]+):(\*)?:(\*)?:([*?]+)$")
+REGEX_WILDCARD_ARN = re.compile(r"^arn:aws:([*\w]+):([*?]*):([*?]*):([*?]+)$")
 
 
 """
 Check for iam arns
 It has 2 groups. The first one for account id, the last one for resource id
 Valid:
-- arn:aws:iam::437628376:not-root
+- arn:aws:iam::123456789012:not-root
 Invalid:
 - arn:aws:s3:::my_corporate_bucket
 - potato
 """
-REGEX_IAM_ARN = re.compile(r"^arn:aws:iam::(\d*):(.*)$")
+REGEX_IAM_ARN = re.compile(r"^arn:aws:iam::(\d+):(.*)$")
 
 
 """
 Check for sts arns
 It has 2 groups. The first one for account id, the last one for resource id
 Valid:
-- arn:aws:sts::437628376:not-root
+- arn:aws:sts::123456789012:not-root
 Invalid:
 - arn:aws:s3:::my_corporate_bucket
 - potato
 """
-REGEX_STS_ARN = re.compile(r"^arn:aws:sts::(\d*):(.*)$")
+REGEX_STS_ARN = re.compile(r"^arn:aws:sts::(\d+):(.*)$")
 
 
 """
-Check for wildcards after colons
+Check for a wildcard star or wildcards immediately after the last colon
 Valid:
 - *
-- arn:aws:iam::437628376:*
+- arn:aws:iam::123456789012:*
+- arn:aws:iam::123456789012:??????
+- arn:aws:iam::123456789012:?*
 - sns:*
 Invalid:
 - arn:aws:s3:::my_corporate_bucket
@@ -144,4 +151,4 @@ Invalid:
 - potato
 - sns:Get*
 """
-REGEX_HAS_STAR_OR_STAR_AFTER_COLON = re.compile(r"^(\w*:)*\*$")
+REGEX_HAS_STAR_OR_STAR_AFTER_COLON = re.compile(r"^(\w*:)*[*?]+$")
